@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20221130';
+our $VERSION = '0.20221228';
 
-# Table last modified: 2022-11-30
+# Table last modified: 2022-12-28
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -65,7 +65,7 @@ our %ZIP_TABLE = (
     '059' => '(?:(?:1(?:39[2-6]|59[2-6]|69[23]|292)|0(?:59[2568]|99[3578]|49[236])|2(?:[14]92|598)|8[67]01|3195))',
     '060' => '(?:8(?:5(?:[38]\d|4[1-9]|[12][0-35-9]|6[0135-9]|7[02-9]|0[1-68]|5[0-46-9])|6(?:1\d|5[14-68]|8[6-8]|7[016-8]|0[1-9]|6[16-8]|2[1-57-9]|4[0-46-9]|3[0-24-9])|7(?:11|67|76|2[015]|9[5-7]|0[35-7])|406))',
     '061' => '(?:(?:1(?:39[2-6]|49[236-8]|19[256])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292|8501))',
-    '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68]|5[56])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
+    '062' => '(?:8(?:6(?:86|1[278]|0[1-357-9]|3[0135]|2[24]|4[12]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:22|0[17]|5[58]|[18][05])|6(?:0[1-36-8]|1[12]|4[15])))',
     '064' => '(?:8(?:5(?:2[1-46]|1[024-689]|6[0-7]|4[0-356]|5[014-8]|8[169]|0[23569]|7[0157]|3[35-7])|6(?:09|2[0-2489]|4[4589]|1[01]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:0[19]|3[139]|1[0-2])))',
@@ -116,7 +116,7 @@ our %ZIP_TABLE = (
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
     '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|2[458]|1[1246]|3[0138]|0[1-35689]|5[015-8]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
-    '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|8[16]|1[0-2]|0[1-48]|6[0-378])|7(?:01|1[0-29])|139|311))',
+    '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
     '116' => '(?:8(?:5(?:71|6[127]|2[1-4]|5[0-46]|8[014-8]|4[0134689]|0[1-3578]|3[237])|621))',
@@ -143,7 +143,7 @@ our %ZIP_TABLE = (
     '150' => '(?:8(?:5(?:45|6[37]|2[256]|0[1-357-9]|7[57]|8[578]|1[0-24-7]|5[1-5]|3[038])|3(?:19|4[03]|7[37]|3[0368]|0[17]|8[45]|2[24-8]|5[05]|6[036])|4(?:12|36|55|0[289]|8[28]|4[08])|9(?:02|11|40|55|67|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:[34]\d|0[2-79]|5[024589]|1[016-9]|6[1-35-9]|2[0-57-9]|9[0-2]|7[0-46-8]|8[02-7])|6(?:5[1-3]|7[1-7]|0[01])|40[14]|070))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
-    '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|3[0169]|1[02568])|6(?:01|40|1[06]|8[78]|2[02]|6[025689]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
+    '153' => '(?:8(?:5(?:7[1378]|2[0-356]|6[057]|5[0-68]|4[0135]|8[0-25-79]|0[1-68]|1[02568]|3[01679])|6(?:01|40|1[06]|8[78]|6[025689]|2[026]|5[02-57]|3[013568]|7[017])|9(?:1[134]|0[246]|2[357]|3[034679])))',
     '154' => '(?:8(?:5(?:8[0-245]|4[3-5]|3[02369]|6[05-8]|2[0135]|0[3-69]|5[1-5]|1[0156]|7[017])|7(?:03|32)))',
     '155' => '(?:86(?:10|26|33|55|6[38]))',
     '156' => '(?:8(?:5(?:33|55|88|0[246]|2[02]|1[01])|666))',
@@ -249,7 +249,7 @@ our %ZIP_TABLE = (
     '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
     '271' => '(?:8(?:5(?:01|22|3[03]|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
     '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|019[35]))',
-    '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|27)|7(?:10|33))|019[2357]))',
+    '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
     '276' => '(?:85(?:01|80|2[3-7]))',
@@ -278,7 +278,7 @@ our %ZIP_TABLE = (
     '302' => '(?:(?:85(?:0[12]|8[56])|0198))',
     '303' => '(?:850[13])',
     '304' => '(?:8[56]01)',
-    '305' => '(?:8(?:5(?:85|0[1-6]|5[05]|7[1-7]|2[01]|1[05-9]|6[013-9])|6(?:42|66|8[67]|0[12459])|701))',
+    '305' => '(?:8(?:5(?:85|0[1-6]|5[05]|7[1-7]|2[01]|1[05-9]|6[013-9])|6(?:42|66|8[67]|0[12459])|70[12]))',
     '306' => '(?:(?:0(?:49[235]|[236]92|595)|86(?:01|86)))',
     '307' => '(?:8[56]01)',
     '308' => '(?:(?:8(?:5(?:[45]0|2[1-4]|1[0-3])|6(?:[03]8|16))|019[34]))',
@@ -303,7 +303,7 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:25|90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
+    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -424,7 +424,7 @@ our %ZIP_TABLE = (
     '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[05]1|[48]0|2[06]|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
-    '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|7(?:58|65|77|0[124])|6(?:11|62|86|0[18])))',
+    '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|6(?:[28]6|11|62|0[18])|7(?:58|65|77|0[124])))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:5(?:[458]5|60|1[25]|[02][15]|3[035])|6(?:[46]8|10|2[06]|3[09]|0[156]|7[01])|777))',
     '456' => '(?:8(?:5(?:23|30|44|0[1-3]|6[07]|1[16]|8[0578]|5[56])|6(?:20|91|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|0[158]|8[058]|6[67]|1[12]|5[0458])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|7[3-578]|2[0-3]|6[05-8]|0[146]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
+    '530' => '(?:(?:8(?:2(?:4[015]|2[1246-8]|3[0249]|5[0-256]|6[0236]|1[0-8]|7[08]|0[1-79]|8[0-378])|5(?:44|2[1-3]|7[3-578]|6[05-8]|0[146]|3[15]|1[1-37]|8[023568]|5[0-3568])|3(?:3[348]|0[148]|8[389]|4[16]|2[1-47]|1[08]|5[035])|4(?:75|80|1[015]|0[128]|4[18])|6(?:60|1[018]|8[089]|0[1256])|79[136-8])|6070))',
     '531' => '(?:(?:8(?:5(?:[67]7|26|88|0[1-3]|1[019]|5[58])|787)|6053))',
     '532' => '(?:8(?:5(?:35|60|88|2[045]|1[1245]|5[58]|0[1578])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -680,7 +680,7 @@ our %ZIP_TABLE = (
     '717' => '(?:8501)',
     '718' => '(?:(?:85(?:[135]0|01|85)|0392))',
     '719' => '(?:(?:0(?:39[238]|19[25]|295)|3(?:19[2-57]|292)|119[235-8]))',
-    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|2[024-7]|0[1-37-9])|6(?:01|50|4[0135]|3[6-9]))|039[278]|219[25]))',
+    '720' => '(?:(?:8(?:5(?:55|1[0-2578]|3[156]|0[1-47-9]|2[024-7])|6(?:01|50|4[0135]|3[6-9]))|039[278]|219[25]))',
     '721' => '(?:8(?:5(?:7[5-7]|6[47]|2[28]|8[568]|4[0135]|1[0145]|5[01568]|0[125])|6(?:31|88|0[17])))',
     '722' => '(?:(?:8(?:5(?:10|0[1-35-8])|60[1245])|2(?:19[238]|49[2-4]|39[23])|1(?:19[23]|[47]92)|039[23]))',
     '723' => '(?:8(?:5(?:01|20|55|1[0-25])|6(?:01|86|1[01])))',
@@ -718,8 +718,8 @@ our %ZIP_TABLE = (
     '757' => '(?:(?:8(?:5(?:11|85)|6(?:34|86))|029[28]))',
     '758' => '(?:8(?:6(?:15|86|4[58])|5(?:[58]5|70)))',
     '759' => '(?:(?:(?:22|55)92|029[2357]|419[2468]|659[25]))',
-    '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|2[0-57]|6[0-246-9]|8[0235689]|1[0-8]|7[0-69]|0[2-578])|6(?:71|8[6-8]|1[458]|6[0178]|3[04689]|5[05]|4[48]|2[013-6]|0[13478])))',
-    '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
+    '760' => '(?:8(?:5(?:90|4[5-7]|5[0-2457-9]|3[0346-9]|2[0-57]|6[0-246-9]|8[0235689]|1[0-8]|7[0-69]|0[2-578])|6(?:71|8[6-8]|6[0178]|3[04689]|5[05]|1[0458]|4[48]|2[013-6]|0[13478])))',
+    '761' => '(?:(?:8(?:5(?:[014]1|20|8[124-689]|7[78]|6[5-7]|3[38]|5[0158])|601|777)|0(?:1(?:8[5-9]|9[2-8])|39[3-7]|49[23]|79[35]|692)|4(?:4(?:89|9[2-8])|3(?:88|9[235-8])|19[2-4])|1(?:79[2-5]|49[2-4]|592)|2(?:39[2356]|49[23])))',
     '762' => '(?:8(?:5(?:50|1[015]|0[23578])|60[12]))',
     '763' => '(?:8(?:5(?:0[1-478]|1[0-368])|60[358]))',
     '764' => '(?:85(?:20|0[1-3578]|1[01]))',
@@ -938,7 +938,7 @@ our %ZIP_TABLE = (
     '981' => '(?:(?:3(?:2(?:8[0178]|9[235-8])|6(?:8[0-24-68]|9[278])|1(?:9[2-5]|8[0589])|49[4-7]|[35]92)|85(?:10|33|85|6[03]|5[0-26-8]|0[25]|7[07]|2[235]|4[035])|1(?:5(?:8[1-3]|9[2356])|29[2-58])|4(?:29[2-4]|392)|0394|2192))',
     '982' => '(?:8(?:5(?:31|44|66|77|2[13]|8[58]|5[15]|1[01]|0[125])|601|798))',
     '983' => '(?:8(?:5(?:70|85|6[0257]|0[1247]|3[367]|4[35]|2[023]|1[1-37]|5[1256])|6(?:01|22|39)|477))',
-    '984' => '(?:8(?:5(?:0[135]|8[045]|7[057]|2[25]|6[0178]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
+    '984' => '(?:8(?:5(?:0[135]|7[057]|2[25]|6[0178]|8[0458]|3[0389]|1[0-2689]|5[0-3578]|4[035])|6(?:42|54|7[056]|0[13]|8[068]|6[689])))',
     '985' => '(?:8(?:5(?:77|5[015]|2[12]|1[01]|0[12467]|3[13578])|6(?:55|0[17])))',
     '986' => '(?:(?:85(?:40|55|0[17]|2[25]|8[05])|0(?:195|792)|229[23]))',
     '987' => '(?:(?:2(?:29[23]|59[23]|195|392)|0(?:59[235]|19[25]|792)|860[23578]|139[35]))',
